@@ -27,7 +27,7 @@ my $dev      = 0;
 my $psize    = 1;
 my $noaccel  = FALSE;
 my $nosplash = FALSE;
-my $ignore_x = FALSE;
+our $ignore_x : shared = FALSE;
 my $delay    = 3;
 my $threads  = Sys::CPU::cpu_count();
 $threads    -= 1 if ($threads > 1);
